%global momorel 3

%define use_nss 1
%define ldap_support 1
%define static_ldap 1
%define krb5_support 1
%define nntp_support 1

%define glib2_version 2.15.3
%define gtk2_version 2.10.0
%define gtk_doc_version 1.9
%define intltool_version 0.35.5
%define libbonobo_version 2.20.3
%define orbit2_version 2.9.8
%define soup_version 2.3.0

%define eds_base_version 2.22
%define eds_api_version 1.2

%define use_gnome_keyring 1
%define support_imap4_provider 0

%define camel_provider_dir %{_libdir}/evolution-data-server-%{eds_api_version}/camel-providers
%define eds_extensions_dir %{_libdir}/evolution-data-server-%{eds_api_version}/extensions

# Use stricter build settings than required by upstream.
%define strict_build_settings 1

### Abstract ###

Name: evolution-data-server
Version: 2.22.3
Release: %{momorel}m%{?dist}
License: LGPL
Group: System Environment/Libraries
Summary: Backend data server for Evolution
URL: http://www.gnome.org/projects/evolution/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Source0: ftp://ftp.gnome.org/pub/GNOME/sources/%{name}/2.22/%{name}-%{version}.tar.bz2
NoSource: 0

### Patches ###

# Remove gnome-common macros from configure.in.
Patch10: evolution-data-server-1.8.0-no-gnome-common.patch

# RH bug #202309
Patch11: evolution-data-server-1.7.91-maybe-fix-crash.patch

# RH bug #215702 / GNOME bug #487988
Patch12: evolution-data-server-1.8.0-fix-ldap-query.patch

# GNOME bug #373146
Patch13: evolution-data-server-1.10.1-camel-folder-summary-crash.patch

# RH bug #243296
Patch14: evolution-data-server-1.11.5-fix-64bit-acinclude.patch

Patch15: evolution-data-server-2.22.0-implicit-function-declaration.patch

# RH bug #296671 / GNOME bug #500389
Patch16: evolution-data-server-2.22.0-e2k-global-catalog.patch

# Security
Patch17: evolution-data-server-2.22.3-CVE-2009-0547.patch
Patch18: evolution-data-server-2.22.3-CVE-2009-0582.patch

### Build Dependencies ###

BuildRequires: GConf2-devel
BuildRequires: ORBit2-devel >= %{orbit2_version}
BuildRequires: bison
BuildRequires: db4-devel
BuildRequires: flex
BuildRequires: gettext
BuildRequires: glib2-devel >= %{glib2_version}
BuildRequires: gnome-vfs2-devel
BuildRequires: gnutls-devel >= 2.4.1
BuildRequires: gtk-doc >= %{gtk_doc_version}
BuildRequires: gtk2-devel >= %{gtk2_version}
BuildRequires: intltool >= %{intltool_version}
BuildRequires: libbonobo-devel >= %{libbonobo_version}
BuildRequires: libglade2-devel
BuildRequires: libgnome-devel
BuildRequires: libgnomeui-devel
BuildRequires: libsoup-devel >= %{soup_version}
BuildRequires: libtool

%if %{use_nss}
BuildRequires: nspr-devel
BuildRequires: nss-devel
%else
BuildRequires: openssl-devel
%endif

%if %{ldap_support}
%if %{static_ldap}
BuildRequires: openldap-evolution-devel
BuildRequires: openssl-devel
%else
BuildRequires: openldap-devel >= 2.0.11 
%endif
%endif

%if %{krb5_support} 
BuildRequires: krb5-devel 
# tweak for krb5 1.2 vs 1.3
%define krb5dir /usr/kerberos
#define krb5dir `pwd`/krb5-fakeprefix
%endif

%description
The %{name} package provides a unified backend for programs that work
with contacts, tasks, and calendar information.

It was originally developed for Evolution (hence the name), but is now used
by other packages.

%package devel
Summary: Development files for building against %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: %{name}-doc = %{version}-%{release}
Requires: libbonobo-devel
Requires: libgnome-devel
Requires: libsoup-devel

%description devel
Development files needed for building things which link against %{name}.

%package doc
Summary: Documentation files for %{name}
Group: Development/Libraries

%description doc
This package contains developer documentation for %{name}.

%prep
%setup -q

%patch10 -p1 -b .no-gnome-common
%patch11 -p1 -b .maybe-fix-crash
%patch12 -p1 -b .fix-ldap-query
%patch13 -p1 -b .camel-folder-summary-crash
%patch14 -p1 -b .fix-64bit-acinclude
%patch15 -p1 -b .implicit-function-declaration
#%%patch16 -p1 -b .e2k-global-catalog
%patch17 -p1 -b .CVE-2009-0582~
%patch18 -p1 -b .CVE-2009-0587~

mkdir -p krb5-fakeprefix/include
mkdir -p krb5-fakeprefix/lib
mkdir -p krb5-fakeprefix/%{_lib}

%build
%if %{ldap_support}

%if %{static_ldap}
%define ldap_flags --with-openldap=%{_libdir}/evolution-openldap --with-static-ldap
# Set LIBS so that configure will be able to link with static LDAP libraries,
# which depend on Cyrus SASL and OpenSSL.  XXX Is the "else" clause necessary?
if pkg-config openssl ; then
	export LIBS="-lsasl2 `pkg-config --libs openssl`"
else
	export LIBS="-lsasl2 -lssl -lcrypto"
fi
%else
%define ldap_flags --with-openldap=yes
%endif

%else
%define ldap_flags --without-openldap
%endif

%if %{krb5_support}
%define krb5_flags --with-krb5=%{krb5dir}
%else
%define krb5_flags --without-krb5
%endif

%if %{nntp_support}
%define nntp_flags --enable-nntp=yes
%else
%define nntp_flags --enable-nntp=no
%endif

%if %{use_nss}
%define ssl_flags --enable-nss=yes --enable-smime=yes
%else
%define ssl_flags --enable-openssl=yes
%endif

%if %{use_nss}
if ! pkg-config --exists nss; then 
  echo "Unable to find suitable version of nss to use!"
  exit 1
fi
%endif

%if %{use_gnome_keyring}
%define keyring_flags --enable-gnome-keyring
%else
%define keyring flags --disable-gnome-keyring
%endif

%if %{support_imap4_provider}
%define imap4_flags --enable-imap4=yes
%else
%define imap4_flags --enable-imap4=no
%endif

export CPPFLAGS="-I%{_includedir}/et"
export CFLAGS="$RPM_OPT_FLAGS -DLDAP_DEPRECATED -fPIC -I%{_includedir}/et"
%if ! %{use_nss}
if pkg-config openssl ; then
	CFLAGS="$CFLAGS `pkg-config --cflags openssl`"
	LDFLAGS="$LDFLAGS `pkg-config --libs-only-L openssl`"
fi
%endif

# Add stricter build settings here as the source code gets cleaned up.
# We want to make sure things like compiler warnings and avoiding deprecated
# functions in the GNOME/GTK+ libraries stay fixed.
#
# Please file a bug report at bugzilla.gnome.org if these settings break
# compilation, and encourage the upstream developers to use them.

%if %{strict_build_settings}
CFLAGS="$CFLAGS \
	-DG_DISABLE_DEPRECATED=1 \
        -DPANGO_DISABLE_DEPRECATED=1 \
	-DGDK_PIXBUF_DISABLE_DEPRECATED=1 \
	-DGDK_DISABLE_DEPRECATED=1 \
	-Wdeclaration-after-statement \
	-Werror-implicit-function-declaration"
%endif

# Regenerate configure to pick up configure.in and acinclude.m4 changes.
aclocal
autoheader
automake
libtoolize
intltoolize --force
autoconf

# See Ross Burton's blog entry for why we want --with-libdb.
# http://www.burtonini.com/blog//computers/eds-libdb-2006-07-18-10-40

%configure \
	--with-libdb=/usr \
	--enable-file-locking=fcntl \
	--enable-dot-locking=no \
	--enable-gtk-doc \
	%ldap_flags %krb5_flags %nntp_flags %ssl_flags %imap4_flags \
	%keyring_flags
export tagname=CC
make %{?_smp_mflags} LIBTOOL=/usr/bin/libtool

%install
rm -rf $RPM_BUILD_ROOT
export tagname=CC
make DESTDIR=$RPM_BUILD_ROOT LIBTOOL=/usr/bin/libtool install

# remove libtool archives for importers and the like
find $RPM_BUILD_ROOT/%{_libdir} -name '*.la' -exec rm {} \;
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/evolution-data-server-%{eds_api_version}/camel-providers/*.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/evolution-data-server-%{eds_api_version}/extensions/*.a

# give the libraries some executable bits 
find $RPM_BUILD_ROOT -name '*.so.*' -exec chmod +x {} \;

%find_lang %{name}-%{eds_base_version}

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}-%{eds_base_version}.lang
%defattr(-,root,root,-)
%doc README COPYING ChangeLog NEWS AUTHORS
%{_libdir}/bonobo/servers/GNOME_Evolution_DataServer_%{eds_api_version}.server
%{_libdir}/libcamel-%{eds_api_version}.so.*
%{_libdir}/libcamel-provider-%{eds_api_version}.so.*
%{_libdir}/libebook-%{eds_api_version}.so.*
%{_libdir}/libecal-%{eds_api_version}.so.*
%{_libdir}/libedata-book-%{eds_api_version}.so.*
%{_libdir}/libedata-cal-%{eds_api_version}.so.*
%{_libdir}/libedataserver-%{eds_api_version}.so.*
%{_libdir}/libedataserverui-%{eds_api_version}.so.*
%{_libdir}/libegroupwise-%{eds_api_version}.so.*
%{_libdir}/libexchange-storage-%{eds_api_version}.so.*
%{_libdir}/libgdata-%{eds_api_version}.so.*
%{_libdir}/libgdata-google-%{eds_api_version}.so.*

%{_libexecdir}/evolution-data-server-%{eds_base_version}
%{_libexecdir}/camel-index-control-%{eds_api_version}
%{_libexecdir}/camel-lock-helper-%{eds_api_version}
%{_datadir}/evolution-data-server-%{eds_base_version}
%{_datadir}/idl/evolution-data-server-%{eds_api_version}
%{_datadir}/pixmaps/evolution-data-server
%dir %{_libdir}/evolution-data-server-%{eds_api_version}
%dir %{camel_provider_dir}
%dir %{eds_extensions_dir}

# Camel providers:
%{camel_provider_dir}/libcamelgroupwise.so
%{camel_provider_dir}/libcamelgroupwise.urls

%{camel_provider_dir}/libcamelhula.so
%{camel_provider_dir}/libcamelhula.urls

%{camel_provider_dir}/libcamelimap.so
%{camel_provider_dir}/libcamelimap.urls

%if %{support_imap4_provider}
%{camel_provider_dir}/libcamelimap4.so
%{camel_provider_dir}/libcamelimap4.urls
%endif

%{camel_provider_dir}/libcamellocal.so
%{camel_provider_dir}/libcamellocal.urls

%{camel_provider_dir}/libcamelnntp.so
%{camel_provider_dir}/libcamelnntp.urls

%{camel_provider_dir}/libcamelpop3.so
%{camel_provider_dir}/libcamelpop3.urls

%{camel_provider_dir}/libcamelsendmail.so
%{camel_provider_dir}/libcamelsendmail.urls

%{camel_provider_dir}/libcamelsmtp.so
%{camel_provider_dir}/libcamelsmtp.urls

# e-d-s extensions:
%{eds_extensions_dir}/libebookbackendfile.so
%{eds_extensions_dir}/libebookbackendgroupwise.so
%{eds_extensions_dir}/libebookbackendldap.so
%{eds_extensions_dir}/libebookbackendvcf.so
%{eds_extensions_dir}/libecalbackendcaldav.so
%{eds_extensions_dir}/libecalbackendcontacts.so
%{eds_extensions_dir}/libecalbackendfile.so
%{eds_extensions_dir}/libecalbackendgoogle.so
%{eds_extensions_dir}/libecalbackendgroupwise.so
%{eds_extensions_dir}/libecalbackendhttp.so
%{eds_extensions_dir}/libecalbackendweather.so

%files devel
%defattr(-,root,root,-)
%{_includedir}/evolution-data-server-%{eds_base_version}
%{_libdir}/libcamel-%{eds_api_version}.so
%{_libdir}/libcamel-provider-%{eds_api_version}.so
%{_libdir}/libebook-%{eds_api_version}.so
%{_libdir}/libecal-%{eds_api_version}.so
%{_libdir}/libedata-book-%{eds_api_version}.so
%{_libdir}/libedata-cal-%{eds_api_version}.so
%{_libdir}/libedataserver-%{eds_api_version}.so
%{_libdir}/libedataserverui-%{eds_api_version}.so
%{_libdir}/libegroupwise-%{eds_api_version}.so
%{_libdir}/libexchange-storage-%{eds_api_version}.so
%{_libdir}/libgdata-%{eds_api_version}.so
%{_libdir}/libgdata-google-%{eds_api_version}.so
%{_libdir}/pkgconfig/camel-%{eds_api_version}.pc
%{_libdir}/pkgconfig/camel-provider-%{eds_api_version}.pc
%{_libdir}/pkgconfig/evolution-data-server-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libebook-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libecal-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libedata-book-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libedata-cal-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libedataserver-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libedataserverui-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libegroupwise-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libexchange-storage-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libgdata-%{eds_api_version}.pc
%{_libdir}/pkgconfig/libgdata-google-%{eds_api_version}.pc

%files doc
%defattr(-,root,root,-)
%{_datadir}/gtk-doc/html/camel
%{_datadir}/gtk-doc/html/libebook
%{_datadir}/gtk-doc/html/libecal
%{_datadir}/gtk-doc/html/libedata-book
%{_datadir}/gtk-doc/html/libedata-cal
%{_datadir}/gtk-doc/html/libedataserver
%{_datadir}/gtk-doc/html/libedataserverui

%changelog
* Fri Mar 20 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (2.22.3-3m)
- [SECURITY] CVE-2009-0547 CVE-2009-0582
- import security patches (Patch17,18) from Fedora 9 (2.22.3-3.fc9)

* Tue Jul 15 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (2.22.3-2m)
- rebuild against gnutls-2.4.1

* Mon Jun 30 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (2.22.3-1m)
- update to 2.22.3

* Wed Jun  4 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (2.22.2-2m)
- rebuild against openssl-0.9.8h-1m

* Thu May 29 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (2.22.2-1m)
- update to 2.22.2

* Mon May  5 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (2.22.1.1-1m)
- update to 2.22.1.1

* Tue Apr 15 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (2.22.1-1m)
- update to 2.22.1

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (2.22.0-2m)
- rebuild against gcc43

* Wed Mar 12 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (2.22.0-1m)
- update to 2.22.0
- sync Fedora

* Sat Mar  8 2008 Masanobu Sato <satoshiga@momonga-linux.org>
- (1.12.3-2m)
- add BuildRequires: gtk-doc

* Mon Jan  7 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.12.3-1m)
- update to 1.12.3

* Mon Nov 26 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.12.2-1m)
- update to 1.12.2

* Sat Oct 20 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (1.12.1-2m)
- rebuild against db4-4.6.21

* Fri Oct 19 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.12.1-1m)
- update to 1.12.1
- sync Fedora

* Thu Sep 20 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.12.0-1m)
- update to 1.12.0

* Tue Jul  3 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.10.3.1-1m)
- update to 1.10.3.1

* Thu Jun 21 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.10.2-2m)
- [SECURITY] CVE-2007-3257
- add patch303 http://svn.gnome.org/viewcvs/evolution-data-server/trunk/camel/providers/imap/camel-imap-folder.c?r1=7720&r2=7817&view=patch

* Tue May 29 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.10.2-1m)
- update to 1.10.2

* Wed Apr 18 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (1.10.1-1m)
- update to 1.10.1

* Sat Mar 17 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.10.0-2m)
- delete patch302 (not used 0 byte)

* Tue Mar 13 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.10.0-1m)
- update to 1.10.0
- modify patch 102

* Thu Mar  1 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.9.92-1m)
- update to 1.9.92

* Sat Feb  3 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.8.3-1m)
- update to 1.8.3

* Wed Nov 22 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.8.2-1m)
- update 1.8.2

* Fri Oct  6 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.8.1-1m)
- update 1.8.1

* Sat Sep 23 2006 NARITA Koichi <pulsar@sea.plala.or.jp>
- (1.8.0-2m)
- rebuild against gnutls-1.4.4-1m

* Thu Sep  7 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.8.0-1m)
- update to 2.8.0

* Tue Aug 15 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.6.3-1m)
- update to 1.6.3

* Thu Jun  1 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.6.2-1m)
- update to 1.6.2

* Thu Apr 13 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.6.1-1m)
- update to 1.6.1

* Sun Apr  9 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (1.6.0-2m)
- rebuild against gnome-vfs

* Sat Apr  8 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.6.0-1m)
- update to 1.6.0
- update patch102 from FC

* Wed Feb 22 2006 Dai OKUYAMA <dai@ouchi.nahi.to>
- (1.4.2.1-2m)
- build with new nspr/nss

* Fri Jan 20 2006 Koichi NARITA <pulsar@sea.plala.or.jp>
- (1.4.2.1-1m)
- update to 1.4.2.1

* Thu Jan 19 2006 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (1.4.1.1-2m)
- -DLDAP_DEPRECATED should be removed ASAP

* Tue Nov  8 2005 Mitsuru Shimamura <smbd@momonga-linux.org>
- (1.4.1.1-1m)
- import from Fedora

* Mon Oct 17 2005 David Malcolm <dmalcolm@redhat.com> - 1.4.1.1-1
- 1.4.1.1

* Mon Oct 17 2005 David Malcolm <dmalcolm@redhat.com> - 1.4.1-2
- Updated patch 102 (fix-implicit-function-declarations) to include fix for 
  http calendar backend (thanks to Peter Robinson)

* Tue Oct  4 2005 David Malcolm <dmalcolm@redhat.com> - 1.4.1-1
- 1.4.1

* Wed Sep 14 2005 Jeremy Katz <katzj@redhat.com> - 1.4.0-2
- rebuild now that mozilla builds on ppc64

* Tue Sep  6 2005 David Malcolm <dmalcolm@redhat.com> - 1.4.0-1
- 1.4.0
- Removed evolution-data-server-1.3.8-fix-libical-vsnprintf.c.patch; a version
  of this is now upstream (was patch 103, added in 1.3.8-2)

* Wed Aug 31 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-6
- Use regular LDAP library for now, rather than evolution-openldap (#167238)

* Tue Aug 30 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-5
- Add -Werror-implicit-function-declaration back to CFLAGS at the make stage, 
  after the configure, to spot 64-bit problems whilst avoiding breaking 
  configuration tests; expand patch 102 to avoid this breaking libdb's CFLAGS
#'

* Wed Aug 24 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-4
- Remove -Werror-implicit-function-declaration from CFLAGS; this broke the
  configuration test for fast mutexes in the internal copy of libdb, and hence
  broke access to local addressbooks (#166742)
- Introduce static_ldap macro; use it to link to static evolution-openldap 
  library, containing NTLM support for LDAP binds (needed by Exchange support)

* Tue Aug 23 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-3
- Updated patch 102 to fix further implicit function declarations

* Tue Aug 23 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-2
- added patch (103) to fix problem with configuration macros in libical's
  vsnprintf.c
#'

* Tue Aug 23 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-1
- 1.3.8
- Add -Werror-implicit-function-declaration to CFLAGS, to avoid 64-bit issues
  and add patch to fix these where they occur (patch 102)

* Mon Aug 15 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.7-2
- rebuild

* Tue Aug  9 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.7-1
- 1.3.7

* Mon Aug  8 2005 Tomas Mraz <tmraz@redhat.com> - 1.3.6.1-2
- rebuild with new gnutls

* Fri Jul 29 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.6.1-1
- 1.3.6.1

* Thu Jul 28 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.6-1
- 1.3.6

* Mon Jul 25 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.5-2
- Added patch to use nspr rather than mozilla-nspr when doing pkg-config tests
  (Patch5: evolution-data-server-1.3.5-nspr_fix.patch)

* Mon Jul 25 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.5-1
- 1.3.5
- Split eds_major (was 1.2) into eds_base_version (1.4) and eds_api_version
  (1.2) to correspond to BASE_VERSION and API_VERSION in configure.in; updated
  rest of specfile accordingly.
- Removed upstreamed patch: 
  evolution-data-server-1.2.0-cope-with-a-macro-called-read.patch

* Wed Jun 27 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.2-4.fc5
- Added leak fixes for GNOME bug 309079 provided by Mark G. Adams

* Wed May 18 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.2-3
- bumped libsoup requirement to 2.2.3; removed mozilla_build_version, using
  pkg-config instead for locating NSPRS and NSS headers/libraries (#158085)

* Mon Apr 11 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.2-2
- added patch to calendar/libecal/e-cal.c to fix missing declaration of open_calendar

* Mon Apr 11 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.2-1
- 1.2.2

* Thu Mar 17 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.1-1
- 1.2.1

* Thu Mar 10 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.0-3
- Removed explicit run-time spec-file requirement on mozilla.
  The Mozilla NSS API/ABI stabilised by version 1.7.3
  The libraries are always located in the libdir
  However, the headers are in /usr/include/mozilla-%{mozilla_build_version}
  and so they move each time the mozilla version changes.
  So we no longer have an explicit mozilla run-time requirement in the specfile; 
  a requirement on the appropriate NSS and NSPR .so files is automagically generated on build.
  We have an explicit, exact build-time version, so that we can find the headers (without
  invoking an RPM query from the spec file; to do so is considered bad practice)
- Introduced mozilla_build_version, to replace mozilla_version
- Set mozilla_build_version to 1.7.6 to reflect current state of tree

* Tue Mar  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.0-2
- Added a patch to deal with glibc defining a macro called "read"

* Tue Mar  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.0-1
- 1.2.0
- Removed patch for GCC 4 as this is now in upstream tarball

* Wed Mar  2 2005 Jeremy Katz <katzj@redhat.com> - 1.1.6-6
- rebuild to fix library linking silliness

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-5
- disabling gtk-doc on ia64 and s390x

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-4
- added macro use_gtk_doc; added missing BuildRequires on gtk-doc; enabled gtk-doc generation on all platforms (had been disabled on ia64)

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-3
- extended patch to deal with camel-groupwise-store-summary.c

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-2
- added patch to fix badly-scoped declaration of "namespace_clear" in camel-imap-store-summary.c

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-1
- 1.1.6

* Tue Feb  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.5-3
- rebuild

* Tue Feb  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.5-2
- forgot to fix sources

* Tue Feb  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.5-1
- 1.1.5

* Thu Jan 27 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.2-1
- Update from unstable 1.1.4.1 to unstable 1.1.1.4.2

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.1-3
- disable gtk-doc generation on ia64 for now

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.1-2
- Exclude ppc64 due to missing mozilla dependency

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.1-1
- Update from 1.0.3 to 1.1.4.1
- Updated eds_major from 1.0 to 1.2; fixed translation search path.
- Removed 64-bit patch for calendar backend hash table; upstream now stores pointers to ECalBackendFactory, rather than GType
- Removed calendar optimisation patch for part of part of bug #141283 as this is now in the upstream tarball
- Added /usr/lib/evolution-data-server-%{eds_major} to cover the extensions, plus the camel code now in e-d-s, rather than evolution
- Added /usr/share/pixmaps/evolution-data-server-%{eds_major} to cover the category pixmaps
- Camel code from evolution is now in evolution-data-server:
  - Added camel-index-control and camel-lock-helper to packaged files
  - Added mozilla dependency code from the evolution package
  - Ditto for LDAP
  - Ditto for krb5
  - Ditto for NNTP support handling
  - Ditto for --enable-file-locking and --enable-dot-locking
- Added requirements on libbonobo, libgnomeui, gnome-vfs2, GConf2, libglade2
- Updated libsoup requirement from 2.2.1 to 2.2.2
- Enabled gtk-doc

* Wed Dec 15 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.3-2
- fixed packaging of translation files to reflect upstream change to GETTEXT_PACKAGE being evolution-data-server-1.0 rather than -1.5

* Wed Dec 15 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.3-1
- update from upstream 1.0.2 to 1.0.3:
  * Address Book
    - prevent e_book_commit_contact from crashing on multiple calls (Diego Gonzalez)
    - prevent file backend from crashing if uid of vcard is NULL (Diego Gonzalez)

  * Calendar
    #XB59904 - Speed up calendar queries (Rodrigo)
    #XB69624 - make changes in evo corresponding to soap schema changes  (Siva)
    - fix libical build for automake 1.9 (Rodney)
    - fix putenv usage for portability (Julio M. Merino Vidal)

  * Updated Translations:
    - sv (Christian Rose)

- Removed patches to fix build on x86_64 and calendar optimisation for XB59004 as these are in the upstream tarball

* Tue Dec  7 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-6
- Amortize writes to a local cache of a webcal calendar, fixing further aspect of #141283 (upstream bugzilla #70267), as posted to mailing list here:
http://lists.ximian.com/archives/public/evolution-patches/2004-December/008338.html
(The groupwise part of that patch did not cleanly apply, so I removed it).

* Thu Dec  2 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-5
- Added fix for #141283 (upstream bugzilla XB 59904), a backported calendar 
optimisation patch posted to upstream development mailing list here:
http://lists.ximian.com/archives/public/evolution-patches/2004-November/008139.html

* Wed Nov  3 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-4
- Added patch to fix usage of GINT_TO_POINTER/GPOINTER_TO_INT for calendar backend GType hash table, breaking on ia64  (#136914)

* Wed Oct 20 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-3
- added workaround for a backend leak that causes the "contacts" calendar 
backend to hold open an EBook for the local contacts (filed upstream at:
http://bugzilla.ximian.com/show_bug.cgi?id=68533 ); this was causing e-d-s to
never lose its last addressbook, and hence never quit.  We workaround this by
detecting this condition and exiting when it occurs, fixing bug #134851 and #134849.

* Tue Oct 12 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-2
- added patch to fix build on x86_64 (had multiple definitions of mutex code in libdb/dbinc.mutex.h)

* Tue Oct 12 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-1
- update from 1.0.1 to 1.0.2
- increased libsoup requirement to 2.2.1 to match configuration script

* Tue Sep 28 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.1-1
- update from 1.0.0 to 1.0.1
- removed patch that fixed warnings in calendar code (now in upstream tarball)

* Mon Sep 20 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.0-2
- fixed various warnings in the calendar code 
  (filed upstream here: http://bugzilla.ximian.com/show_bug.cgi?id=66383)

* Tue Sep 14 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.0-1
- update from 0.0.99 to 1.0.0
- changed path in FTP source location from 0.0 to 1.0

* Tue Aug 31 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.99-1
- update from 0.0.98 to 0.0.99
- increased libsoup requirement to 2.2.0 to match configuration script

* Mon Aug 16 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.98-1
- updated tarball from 0.0.97 to 0.0.98; updated required libsoup version to 2.1.13

* Thu Aug  5 2004 Warren Togami <wtogami@redhat.com> - 0.0.97-2
- pkgconfig -devel Requires libbonobo-devel, libgnome-devel

* Wed Aug  4 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.97-1
- upgraded to 0.0.97; rewrote the package's description
#'

* Mon Jul 26 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Tue Jul 20 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.96-2
- added version numbers to the BuildRequires test for libsoup-devel and ORBit2-devel

* Tue Jul 20 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.96-1
- 0.0.96; libsoup required is now 2.1.12

* Thu Jul  8 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Wed Jul  7 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Tue Jul  6 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.95-1
- 0.0.95

* Thu Jun 17 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.94.1-1
- 0.0.94.1

* Mon Jun  7 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.94-2
- rebuilt

* Mon Jun  7 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.94-1
- 0.0.94

* Wed May 26 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-4
- added ORBit2 requirement

* Fri May 21 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-3
- rebuild again

* Fri May 21 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-2
- rebuilt

* Thu May 20 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-1
- 0.0.93; libsoup required is now 2.1.10

* Wed Apr 21 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.92-1
- Update to 0.0.92; added a define and a requirement on the libsoup version

* Wed Mar 10 2004 Jeremy Katz <katzj@redhat.com> - 0.0.90-1
- 0.0.90

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Jan 26 2004 Jeremy Katz <katzj@redhat.com> - 0.0.6-1
- 0.0.6

* Wed Jan 21 2004 Jeremy Katz <katzj@redhat.com> - 0.0.5-2
- better fix by using system libtool

* Mon Jan 19 2004 Jeremy Katz <katzj@redhat.com> 0.0.5-1
- add some libdb linkage to make the build on x86_64 happy

* Wed Jan 14 2004 Jeremy Katz <katzj@redhat.com> 0.0.5-0
- update to 0.0.5

* Sat Jan  3 2004 Jeremy Katz <katzj@redhat.com> 0.0.4-0
- Initial build.

